@@ -1,3 +1,6 @@
+#ifndef __ARC_CLEINT_COMPUTE_UTILS_H_
+#define __ARC_CLEINT_COMPUTE_UTILS_H_
+
 #include <unistd.h>
 #include <string>
 #include <list>
@@ -34,6 +37,7 @@ class ConsoleRecovery {
   int X
 #endif
 
+
 /// Returns the URLs of computing elements selected by alias, group name, URL or the default ones
 /**
   This helper method gets a list of string representing computing elements. Each item of the list
@@ -130,6 +134,12 @@ public:
                 const std::string& summary = "",
                 const std::string& description = "");
 
+  /// Returns the boolean value indication whether new ARC6 set of target selection options are in use
+  bool isARC6TargetSelectionOptions(Arc::Logger& logger, bool allow_cluster = false);
+
+  /// Implement ARC consistent info/submission endpoint types logic
+  bool canonicalizeARC6InterfaceTypes(Arc::Logger& logger);
+
   bool dryrun;
   bool dumpdescription;
   bool show_credentials;
@@ -149,18 +159,19 @@ public:
   bool show_stdout;
   bool show_stderr;
   bool show_joblog;
-  std::string show_file;
+  bool show_json;
   bool usejobname;
   bool forcedownload;
   bool list_configured_services;
   bool direct_submission;
   bool show_unavailable;
-  bool show_json;
 
   int testjobid;
   int runtime;
   int timeout;
 
+  std::string show_file;
+
   std::string joblist;
   std::string jobidoutfile;
   std::string conffile;
@@ -182,4 +193,16 @@ public:
 
   std::list<std::string> rejectdiscovery;
   std::list<std::string> rejectmanagement;
+
+  // arc6 consistent, intuitive and streamlined target selection:
+  // command line options
+  std::list<std::string> computing_elements;
+  std::list<std::string> registries;
+  std::string requested_submission_endpoint_type;
+  std::string requested_info_endpoint_type;
+  // post-processed interface types
+  std::list<std::string> submit_types;
+  std::list<std::string> info_types;
 };
+
+#endif // __ARC_CLEINT_COMPUTE_UTILS_H_
