@@ -21,34 +21,10 @@ namespace Arc {
 
   Logger TargetInformationRetrieverPluginEMIES::logger(Logger::getRootLogger(), "TargetInformationRetrieverPlugin.EMIES");
 
-  bool TargetInformationRetrieverPluginEMIES::isEndpointNotSupported(const Endpoint& endpoint) const {
-    const std::string::size_type pos = endpoint.URLString.find("://");
-    if (pos != std::string::npos) {
-      const std::string proto = lower(endpoint.URLString.substr(0, pos));
-      return ((proto != "http") && (proto != "https"));
-    }
-
-    return false;
-  }
-
-  static URL CreateURL(std::string service) {
-    std::string::size_type pos1 = service.find("://");
-    if (pos1 == std::string::npos) {
-      service = "https://" + service;
-    } else {
-      std::string proto = lower(service.substr(0,pos1));
-      if((proto != "http") && (proto != "https")) return URL();
-    }
-
-    return service;
-  }
-
   EndpointQueryingStatus TargetInformationRetrieverPluginEMIES::Query(const UserConfig& uc, const Endpoint& cie, std::list<ComputingServiceType>& csList, const EndpointQueryOptions<ComputingServiceType>&) const {
-    EndpointQueryingStatus s(EndpointQueryingStatus::FAILED);
-
     URL url(CreateURL(cie.URLString));
     if (!url) {
-      return s;
+      return EndpointQueryingStatus::FAILED;
     }
 
     logger.msg(DEBUG, "Collecting EMI-ES GLUE2 computing info endpoint information.");
@@ -57,7 +33,7 @@ namespace Arc {
     EMIESClient ac(url, cfg, uc.Timeout());
     XMLNode servicesQueryResponse;
     if (!ac.sstat(servicesQueryResponse)) {
-      return s;
+      return EndpointQueryingStatus(EndpointQueryingStatus::FAILED, ac.failure());
     }
 
     ExtractTargets(url, servicesQueryResponse, csList);
@@ -66,8 +42,8 @@ namespace Arc {
       (*it)->InformationOriginEndpoint = cie;
     }
 
-    if (!csList.empty()) s = EndpointQueryingStatus::SUCCESSFUL;
-    return s;
+    if (csList.empty()) return EndpointQueryingStatus::FAILED;
+    return EndpointQueryingStatus::SUCCESSFUL;
   }
 
   void TargetInformationRetrieverPluginEMIES::ExtractTargets(const URL& url, XMLNode response, std::list<ComputingServiceType>& csList) {
