@@ -10,7 +10,6 @@
 namespace Arc {
 
   class RunPump;
-  class Pid;
 
   /// This class runs an external executable.
   /** It is possible to read from or write to its standard handles or to
@@ -20,19 +19,21 @@ namespace Arc {
   class Run {
     friend class RunPump;
   public:
+    // Interface to container for data received/sent to process.
     class Data {
      public:
       virtual ~Data() {};
-      virtual void Append(char const* data, unsigned int size) {};
-      virtual void Remove(unsigned int size) {};
-      virtual char const* Get() const { return NULL; };
-      virtual unsigned int Size() const { return 0; };
+      virtual void Append(char const* data, unsigned int size) = 0;
+      virtual void Remove(unsigned int size) = 0;
+      virtual char const* Get() const = 0;
+      virtual unsigned int Size() const = 0;
     };
 
   private:
     Run(const Run&);
     Run& operator=(Run&);
   protected:
+    // Container for data pumped through std* channels.
     class StringData: public Data {
      public:
       StringData();
@@ -48,7 +49,7 @@ namespace Arc {
 
     // working directory
     std::string working_directory;
-    // Handles
+    // Std* handles
     int stdout_;
     int stderr_;
     int stdin_;
@@ -59,17 +60,12 @@ namespace Arc {
     StringData stdout_str_wrap_;
     StringData stderr_str_wrap_;
     StringData stdin_str_wrap_;
-    //
+    // Request to keep std* handles of process same as in parent
     bool stdout_keep_;
     bool stderr_keep_;
     bool stdin_keep_;
-    // Signal connections
-    sigc::connection stdout_conn_;
-    sigc::connection stderr_conn_;
-    sigc::connection stdin_conn_;
-    sigc::connection child_conn_;
     // PID of child
-    Pid *pid_;
+    pid_t pid_;
     // Arguments to execute
     std::list<std::string> argv_;
     std::list<std::string> envp_;
@@ -78,16 +74,18 @@ namespace Arc {
     void *initializer_arg_;
     void (*kicker_func_)(void*);
     void *kicker_arg_;
-    // IO handlers
-    bool stdout_handler(Glib::IOCondition cond);
-    bool stderr_handler(Glib::IOCondition cond);
-    bool stdin_handler(Glib::IOCondition cond);
+    // IO handlers are called when data can be sent/received
+    typedef bool (Run::*HandleHandler)();
+    bool stdout_handler();
+    bool stderr_handler();
+    bool stdin_handler();
     // Child exit handler
-    void child_handler(Glib::Pid pid, int result);
-    bool started_;
-    bool running_;
-    bool abandoned_;
-    int result_;
+    typedef bool (Run::*PidHandler)(int);
+    void child_handler(int result);
+    bool started_; // child process was stated
+    bool running_; // child process is running
+    bool abandoned_; // we are interested in this process anymore
+    int result_; // process execution result
     Glib::Mutex lock_;
     Glib::Cond cond_;
     int user_id_;
@@ -128,15 +126,15 @@ namespace Arc {
     }
     /// Return true if execution is going on.
     bool Running(void);
-    /// Return when executable was started.
+    /// Returns time when executable was started.
     Time RunTime(void) {
       return run_time_;
     };
-    /// Return when executable finished executing.
+    /// Return time when executable finished executing.
     Time ExitTime(void) {
       return exit_time_;
     };
-    /// Read from stdout handle of running executable.
+    /// Read from stdout pipe of running executable.
     /** This method may be used while stdout is directed to string, but the
         result is unpredictable.
         \param timeout upper limit for which method will block in milliseconds.
@@ -145,7 +143,7 @@ namespace Arc {
         \param size size of buf
         \return number of read bytes. */
     int ReadStdout(int timeout, char *buf, int size);
-    /// Read from stderr handle of running executable.
+    /// Read from stderr pipe of running executable.
     /** This method may be used while stderr is directed to string, but the
         result is unpredictable.
         \param timeout upper limit for which method will block in milliseconds.
@@ -154,7 +152,7 @@ namespace Arc {
         \param size size of buf
         \return number of read bytes. */
     int ReadStderr(int timeout, char *buf, int size);
-    /// Write to stdin handle of running executable.
+    /// Write to stdin pipe of running executable.
     /** This method may be used while stdin is directed to string, but the
         result is unpredictable.
         \param timeout upper limit for which method will block in milliseconds.
@@ -163,26 +161,26 @@ namespace Arc {
         \param size size of buf
         \return number of written bytes. */
     int WriteStdin(int timeout, const char *buf, int size);
-    /// Associate stdout handle of executable with string.
+    /// Associate stdout pipe of executable with string.
     /** This method must be called before Start(). str object
         must be valid as long as this object exists. */
     void AssignStdout(std::string& str);
     void AssignStdout(Data& str);
-    /// Associate stderr handle of executable with string.
+    /// Associate stderr pipe of executable with string.
     /** This method must be called before Start(). str object
         must be valid as long as this object exists. */
     void AssignStderr(std::string& str);
     void AssignStderr(Data& str);
-    /// Associate stdin handle of executable with string.
+    /// Associate stdin pipe of executable with string.
     /** This method must be called before Start(). str object
         must be valid as long as this object exists. */
     void AssignStdin(std::string& str);
     void AssignStdin(Data& str);
-    /// Keep stdout same as parent's if keep = true.
+    /// Keep stdout same as parent's if keep = true. No pipe will be created.
     void KeepStdout(bool keep = true);
-    /// Keep stderr same as parent's if keep = true.
+    /// Keep stderr same as parent's if keep = true. No pipe will be created.
     void KeepStderr(bool keep = true);
-    /// Keep stdin same as parent's if keep = true.
+    /// Keep stdin same as parent's if keep = true. No pipe will be created.
     void KeepStdin(bool keep = true);
     /// Closes pipe associated with stdout handle.
     void CloseStdout(void);
@@ -190,13 +188,11 @@ namespace Arc {
     void CloseStderr(void);
     /// Closes pipe associated with stdin handle.
     void CloseStdin(void);
-    //void DumpStdout(void);
-    //void DumpStderr(void);
     /// Assign a function to be called just after process is forked but before execution starts.
     void AssignInitializer(void (*initializer_func)(void*), void *initializer_arg);
-    /// Assign a function to be called just after execution ends
+    /// Assign a function to be called just after execution ends. It is executed asynchronously.
     void AssignKicker(void (*kicker_func)(void*), void *kicker_arg);
-    /// Assign working directory of the running process.
+    /// Assign working directory of the process to run.
     void AssignWorkingDirectory(std::string& wd) {
       working_directory = wd;
     }
@@ -208,25 +204,24 @@ namespace Arc {
     void AssignGroupId(int gid) {
       group_id_ = gid;
     }
-    /// Add environment variable to be passed to process being run
+    /// Add environment variable to be passed to process before it is run
     void AddEnvironment(const std::string& key, const std::string& value) {
       AddEnvironment(key+"="+value);
     }
-    /// Add environment variable to be passed to process being run
+    /// Add environment variable to be passed to process before it is run
     void AddEnvironment(const std::string& var) {
       envp_.push_back(var);
     }
-    /// Remove environment variable to be passed to process being run
+    /// Remove environment variable to be passed to process before it is run
     void RemoveEnvironment(const std::string& key) {
       envx_.push_back(key);
     }
     /// Kill running executable.
-    /** First soft kill signal (SIGTERM) is sent to executable. If
-        after timeout seconds executable is still running it's killed
-        completely. Currently this method does not work for Windows OS */
+    /** First soft kill signal (SIGTERM) is sent to executable. If after
+        timeout seconds executable is still running it's killed forcefuly. */
     void Kill(int timeout);
     /// Detach this object from running process.
-    /** After calling this method instance is not associated with external
+    /** After calling this method class instance is not associated with external
         process anymore. As result destructor will not kill process. */
     void Abandon(void);
     /// Call this method after fork() in child process.
