@@ -110,12 +110,40 @@ namespace Arc {
        but runs thread() method instead of specified function. */
     bool start(SimpleCounter* count = NULL);
 
+    virtual ~Thread(void) {};
+
    protected:
     /// Implement this method and put thread functionality into it
     virtual void thread(void) = 0;
 
   };
 
+  template<typename T> class AutoLock {
+  public:
+    AutoLock(T& olock, bool olocked = true) : lock_(olock), locked_(0) {
+      if(olocked) lock();
+    }
+
+    ~AutoLock() {
+      if(locked_ != 0) lock_.unlock();
+      locked_ = 0;
+    }
+
+    void lock() {
+      if(locked_ == 0) lock_.lock();
+      ++locked_;
+    }
+
+    void unlock() {
+      if(locked_ == 1) lock_.unlock();
+      --locked_;
+    }
+
+  private:
+    T& lock_;
+    int locked_;
+  };
+
   /// Simple triggered condition.
   /** Provides condition and semaphor objects in one element.
       \headerfile Thread.h arc/Thread.h  */
