@@ -349,23 +349,34 @@ namespace Arc {
       if (protocol == "s3+https") port = S3_HTTPS_DEFAULT_PORT;
     }
 
-    if (protocol != "ldap" && protocol != "arc" && protocol.find("http") != 0 &&
+    // TODO: for ARC 7 move these metadata options into the normal ARC URL options
+    if (protocol != "ldap" && protocol != "arc" &&
         (protocol != "root" || path.find('?') == std::string::npos)) {
       pos2 = path.rfind('=');
       if (pos2 != std::string::npos) {
         pos3 = path.rfind(':', pos2);
         if (pos3 != std::string::npos) {
-          pos = pos3;
-          while (pos2 != std::string::npos && pos3 != std::string::npos) {
-            pos2 = path.rfind('=', pos);
-            if (pos2 != std::string::npos) {
-              pos3 = path.rfind(':', pos2);
-              if (pos3 != std::string::npos)
-                pos = pos3;
+          // Check that options are in the allowed list of metadata options
+          std::string option_name = path.substr(pos3+1, pos2-(pos3+1));
+          if (option_name == "checksumtype" || option_name == "checksumvalue" ||  option_name == "guid") {
+            pos = pos3;
+            while (pos2 != std::string::npos && pos3 != std::string::npos) {
+              pos2 = path.rfind('=', pos);
+              if (pos2 != std::string::npos) {
+                pos3 = path.rfind(':', pos2);
+                if (pos3 != std::string::npos) {
+                  option_name = path.substr(pos3+1, pos2-(pos3+1));
+                  if (option_name == "checksumtype" || option_name == "checksumvalue" ||  option_name == "guid") {
+                    pos = pos3;
+                  } else {
+                    break;
+                  }
+                }
+              }
             }
+            metadataoptions = ParseOptions(path.substr(pos + 1), ':', encoded);
+            path = path.substr(0, pos);
           }
-          metadataoptions = ParseOptions(path.substr(pos + 1), ':', encoded);
-          path = path.substr(0, pos);
         }
       }
     }
@@ -399,6 +410,8 @@ namespace Arc {
     if (protocol == "http" ||
         protocol == "https" ||
         protocol == "httpg" ||
+        protocol == "dav" ||
+        protocol == "davs" ||
         protocol == "arc" ||
         protocol == "srm" ||
         protocol == "root" ||
