@@ -146,7 +146,7 @@ namespace Arc {
         if(err != SQLITE_OK) {
           handleError(NULL, err);
           tearDown();
-          throw SQLiteException(IString("Unable to transfer drop jobs in data base (%s)", name).str(), err);
+          throw SQLiteException(IString("Unable to drop jobs in data base (%s)", name).str(), err);
         }
         err = sqlite3_exec_nobusy(jobDB, "ALTER TABLE jobs_new RENAME TO jobs", NULL, NULL, NULL);   
         if(err != SQLITE_OK) {
@@ -172,9 +172,8 @@ namespace Arc {
         tearDown();
         throw SQLiteException(IString("Failed checking database (%s)", name).str(), err);
       }
+      JobInformationStorageSQLite::logger.msg(DEBUG, "Job database connection established successfully (%s)", name);
     }
-
-    JobInformationStorageSQLite::logger.msg(DEBUG, "Job database created successfully (%s)", name);
   }
 
   void JobInformationStorageSQLite::JobDB::tearDown() {
@@ -568,7 +567,6 @@ namespace Arc {
     jobs.clear();
 
     try {
-      int ret;
       JobDB db(name);
       std::string sqlcmd = "SELECT * FROM jobs";
       ReadJobsCallbackArg carg(jobs, NULL, NULL, &rejectEndpoints);
@@ -593,7 +591,6 @@ namespace Arc {
     jobs.clear();
     
     try {
-      int ret;
       JobDB db(name);
       std::string sqlcmd = "SELECT * FROM jobs";
       ReadJobsCallbackArg carg(jobs, &jobIdentifiers, &endpoints, &rejectEndpoints);
