@@ -18,14 +18,13 @@ namespace DataStaging {
 
   /** Set up logging. Should be called at the start of each thread method. */
   void setUpLogger(DTR_ptr request) {
+    // Move DTR destinations from DTR logger to Root logger to catch all messages.
     // disconnect this thread's root logger
     Arc::Logger::getRootLogger().setThreadContext();
+    request->get_logger()->setThreadContext();
     Arc::Logger::getRootLogger().removeDestinations();
     Arc::Logger::getRootLogger().addDestinations(request->get_logger()->getDestinations());
-    // now disconnect the DTR logger - the root logger is enabled and we
-    // don't want duplicate messages. IMPORTANT: the DTR logger must be
-    // re-enabled at the end of the thread
-    request->disconnect_logger();
+    request->get_logger()->removeDestinations();
   }
 
   Processor::Processor() {
@@ -51,6 +50,7 @@ namespace DataStaging {
     // Create cache using configuration
     Arc::FileCache cache(request->get_cache_parameters().cache_dirs,
                          request->get_cache_parameters().drain_cache_dirs,
+                         request->get_cache_parameters().readonly_cache_dirs,
                          request->get_parent_job_id(),
                          request->get_local_user().get_uid(),
                          request->get_local_user().get_gid());
@@ -62,7 +62,6 @@ namespace DataStaging {
                             DTRErrorStatus::ERROR_DESTINATION,
                             "Failed to create cache");
       request->set_status(DTRStatus::CACHE_CHECKED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
       return;
     }
@@ -101,7 +100,6 @@ namespace DataStaging {
           request->get_logger()->msg(Arc::INFO, "Will wait around %is", cache_wait_time);
           request->set_process_time(cache_wait_period);
 
-          request->connect_logger();
           DTR::push(request, SCHEDULER);
           return;
         }
@@ -177,7 +175,6 @@ namespace DataStaging {
       break;
     }
     request->set_status(DTRStatus::CACHE_CHECKED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -201,7 +198,6 @@ namespace DataStaging {
                                   DTRErrorStatus::ERROR_SOURCE,
                                   "Could not resolve any source replicas for " + request->get_source()->str() + ": " + std::string(res));
         request->set_status(DTRStatus::RESOLVED);
-        request->connect_logger();
         DTR::push(request, SCHEDULER);
         return;
       }
@@ -224,7 +220,6 @@ namespace DataStaging {
                                   DTRErrorStatus::ERROR_SOURCE,
                                   "Could not resolve any source replicas for " + request->get_source()->str());
         request->set_status(DTRStatus::RESOLVED);
-        request->connect_logger();
         DTR::push(request, SCHEDULER);
         return;
       }
@@ -235,7 +230,6 @@ namespace DataStaging {
     // destination will be done in the pre-clean stage after deleting.
     if (!request->is_replication() && request->get_destination()->GetURL().Option("overwrite") == "yes") {
       request->set_status(DTRStatus::RESOLVED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
       return;
     }
@@ -250,7 +244,6 @@ namespace DataStaging {
                                   DTRErrorStatus::ERROR_DESTINATION,
                                   "Could not resolve any destination replicas for " + request->get_destination()->str() + ": " + std::string(res));
         request->set_status(DTRStatus::RESOLVED);
-        request->connect_logger();
         DTR::push(request, SCHEDULER);
         return;
       }
@@ -265,7 +258,6 @@ namespace DataStaging {
                                   DTRErrorStatus::NO_ERROR_LOCATION,
                                   "No locations for destination different from source found for " + request->get_destination()->str());
         request->set_status(DTRStatus::RESOLVED);
-        request->connect_logger();
         DTR::push(request, SCHEDULER);
         return;
       }
@@ -283,7 +275,6 @@ namespace DataStaging {
     }
     // finished with resolving - send back to scheduler
     request->set_status(DTRStatus::RESOLVED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -341,7 +332,6 @@ namespace DataStaging {
       }
 
       request->set_status(DTRStatus::RESOLVED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
     }
   }
@@ -385,7 +375,6 @@ namespace DataStaging {
     }
     // finished querying - send back to scheduler
     request->set_status(DTRStatus::REPLICA_QUERIED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -435,7 +424,6 @@ namespace DataStaging {
         request->get_destination()->SetMeta(*request->get_source());
       }
       request->set_status(DTRStatus::REPLICA_QUERIED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
     }
   }
@@ -507,7 +495,6 @@ namespace DataStaging {
                                 "Failed to pre-clean destination " + request->get_destination()->str() + ": " + std::string(res));
     }
     request->set_status(DTRStatus::PRE_CLEANED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -555,7 +542,6 @@ namespace DataStaging {
     }
     if (request->error()) {
       request->set_status(DTRStatus::STAGED_PREPARED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
       return;
     }
@@ -594,7 +580,6 @@ namespace DataStaging {
     // set to staged prepared if we don't have to wait for source or destination
     if (request->get_status() != DTRStatus::STAGING_PREPARING_WAIT)
       request->set_status(DTRStatus::STAGED_PREPARED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -637,7 +622,6 @@ namespace DataStaging {
       }
     }
     request->set_status(DTRStatus::REQUEST_RELEASED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -679,7 +663,6 @@ namespace DataStaging {
     }
     // finished with registration - send back to scheduler
     request->set_status(DTRStatus::REPLICA_REGISTERED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
@@ -693,6 +676,7 @@ namespace DataStaging {
 
     Arc::FileCache cache(request->get_cache_parameters().cache_dirs,
                          request->get_cache_parameters().drain_cache_dirs,
+                         request->get_cache_parameters().readonly_cache_dirs,
                          request->get_parent_job_id(),
                          request->get_local_user().get_uid(),
                          request->get_local_user().get_gid());
@@ -703,7 +687,6 @@ namespace DataStaging {
                             DTRErrorStatus::ERROR_DESTINATION,
                             "Failed to create cache for " + request->get_source()->str());
       request->set_status(DTRStatus::CACHE_PROCESSED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
       return;
     }
@@ -724,7 +707,6 @@ namespace DataStaging {
         }
       }
       request->set_status(DTRStatus::CACHE_PROCESSED);
-      request->connect_logger();
       DTR::push(request, SCHEDULER);
       return;
     }
@@ -767,7 +749,6 @@ namespace DataStaging {
     }
     if (was_downloaded) cache.Stop(canonic_url);
     request->set_status(DTRStatus::CACHE_PROCESSED);
-    request->connect_logger();
     DTR::push(request, SCHEDULER);
   }
 
