@@ -114,7 +114,7 @@ namespace DataStaging {
 
   void Scheduler::log_to_root_logger(Arc::LogLevel level, const std::string& message) {
     Arc::Logger::getRootLogger().addDestinations(root_destinations);
-    logger.msg(level, message);
+    logger.msg(level, "%s", message);
     Arc::Logger::getRootLogger().removeDestinations();
   }
 
@@ -171,18 +171,18 @@ namespace DataStaging {
       // Use next replica
       // Clear the error flag to resume normal workflow
       request->reset_error_status();
-      request->get_logger()->msg(Arc::INFO, "Using next %s replica", source_error ? "source" : "destination");
+      request->get_logger()->msg(Arc::INFO, "Using next %s replica", source_error ? istring("source") : istring("destination"));
       // Perhaps not necessary to query replica again if the error was in the destination
       // but the error could have been caused by a source problem during transfer
       request->set_status(DTRStatus::QUERY_REPLICA);
     }
     else {
       // No replicas - move to appropriate state for the post-processor to do cleanup
-      request->get_logger()->msg(Arc::ERROR, "No more %s replicas", source_error ? "source" : "destination");
+      request->get_logger()->msg(Arc::ERROR, "No more %s replicas", source_error ? istring("source") : istring("destination"));
       if (request->get_destination()->IsIndex()) {
         request->get_logger()->msg(Arc::VERBOSE, "Will clean up pre-registered destination");
         request->set_status(DTRStatus::REGISTER_REPLICA);
-      } else if (!request->get_cache_parameters().cache_dirs.empty() &&
+      } else if (!(request->get_cache_parameters().cache_dirs.empty() && request->get_cache_parameters().readonly_cache_dirs.empty()) &&
                  (request->get_cache_state() == CACHE_ALREADY_PRESENT || request->get_cache_state() == CACHEABLE)) {
         request->get_logger()->msg(Arc::VERBOSE, "Will release cache locks");
         request->set_status(DTRStatus::PROCESS_CACHE);
@@ -250,7 +250,8 @@ namespace DataStaging {
         request->get_transfer_share(), request->get_priority());
 
     // Normal workflow is CHECK_CACHE
-    if (request->get_cache_state() == NON_CACHEABLE || request->get_cache_parameters().cache_dirs.empty()) {
+    if (request->get_cache_state() == NON_CACHEABLE ||
+        (request->get_cache_parameters().cache_dirs.empty() && request->get_cache_parameters().readonly_cache_dirs.empty())) {
       request->get_logger()->msg(Arc::VERBOSE, "File is not cacheable, was requested not to be cached or no cache available, skipping cache check");
       request->set_status(DTRStatus::CACHE_CHECKED);
     } else {
@@ -325,7 +326,8 @@ namespace DataStaging {
     if(request->error()){
       // It's impossible to download anything, since no replica location is resolved
       // if cacheable, move to PROCESS_CACHE, the post-processor will do the cleanup
-      if (request->get_cache_state() == CACHEABLE && !request->get_cache_parameters().cache_dirs.empty()) {
+      if (request->get_cache_state() == CACHEABLE &&
+          !(request->get_cache_parameters().cache_dirs.empty() && request->get_cache_parameters().cache_dirs.empty())) {
         request->get_logger()->msg(Arc::ERROR, "Problem with index service, will release cache lock");
         request->set_status(DTRStatus::PROCESS_CACHE);
       // else go to end state
@@ -512,7 +514,7 @@ namespace DataStaging {
     } else if (request->get_destination()->IsIndex()) {
       // Normal workflow is REGISTER_REPLICA
       request->get_logger()->msg(Arc::VERBOSE, "Will %s in destination index service",
-                                 ((request->error() || request->cancel_requested()) ? "unregister":"register"));
+                                 ((request->error() || request->cancel_requested()) ? istring("unregister") : istring("register")));
       request->set_status(DTRStatus::REGISTER_REPLICA);
     } else {
       request->get_logger()->msg(Arc::VERBOSE, "Destination is not index service, skipping replica registration");
@@ -530,7 +532,8 @@ namespace DataStaging {
        request->get_error_status().GetLastErrorState() == DTRStatus::REGISTERING_REPLICA) {
       request->get_logger()->msg(Arc::ERROR, "Error registering replica, moving to end of data staging");
       request->set_status(DTRStatus::CACHE_PROCESSED);
-    } else if (!request->get_cache_parameters().cache_dirs.empty() &&
+    } else if (!(request->get_cache_parameters().cache_dirs.empty() &&
+                 request->get_cache_parameters().readonly_cache_dirs.empty()) &&
                (request->get_cache_state() == CACHE_ALREADY_PRESENT ||
                 request->get_cache_state() == CACHE_DOWNLOADED ||
                 request->get_cache_state() == CACHEABLE ||
@@ -1154,12 +1157,6 @@ namespace DataStaging {
           // Stuck in processing thread for more than one hour - assume a hang
           // and try to recover and retry. It is potentially dangerous if a
           // stuck thread wakes up.
-          // Need to re-connect logger as it was disconnected in Processor thread
-          tmp->connect_logger();
-          // Tell DTR not to delete LogDestinations - this creates a memory leak
-          // but avoids crashes when stuck threads wake up. A proper fix could
-          // be using autopointers in Logger
-          tmp->set_delete_log_destinations(false);
           tmp->get_logger()->msg(Arc::WARNING, "Processing thread timed out. Restarting DTR");
           tmp->set_error_status(DTRErrorStatus::INTERNAL_PROCESS_ERROR,
                                 DTRErrorStatus::NO_ERROR_LOCATION,
