@@ -387,7 +387,7 @@ GridManager::GridManager(GMConfig& config):tostop_(false), config_(config) {
 
 GridManager::~GridManager(void) {
   if(!jobs_) return; // Not initialized at all
-  logger.msg(Arc::INFO, "Shutting down job processing");
+  logger.msg(Arc::INFO, "Requesting to stop job processing");
   // Tell main thread to stop
   tostop_ = true;
   // Wait for main thread
@@ -395,7 +395,9 @@ GridManager::~GridManager(void) {
     if(jobs_) // Race condition again
       jobs_->RequestAttention(); // Kick jobs processor to release control
     if(active_.wait(1000)) break;
+    logger.msg(Arc::VERBOSE, "Waiting for main job processing thread to exit");
   }
+  logger.msg(Arc::INFO, "Stopped job processing");
 }
 
 } // namespace ARex
