@@ -101,6 +101,7 @@ void GMConfig::SetDefaults() {
 
   enable_arc_interface = false;
   enable_emies_interface = false;
+  enable_publicinfo = false;
 
   cert_dir = Arc::GetEnv("X509_CERT_DIR");
   voms_dir = Arc::GetEnv("X509_VOMS_DIR");
@@ -122,7 +123,8 @@ void GMConfig::Print() const {
   logger.msg(Arc::INFO, "\tdefault ttl      : %u", keep_finished);
 
   std::vector<std::string> conf_caches = cache_params.getCacheDirs();
-  if(conf_caches.empty()) {
+  std::vector<std::string> readonly_caches = cache_params.getReadOnlyCacheDirs();
+  if(conf_caches.empty() && readonly_caches.empty()) {
     logger.msg(Arc::INFO,"No valid caches found in configuration, caching is disabled");
     return;
   }
@@ -132,6 +134,9 @@ void GMConfig::Print() const {
     if ((*i).find(" ") != std::string::npos)
       logger.msg(Arc::INFO, "\tCache link dir   : %s", (*i).substr((*i).find_last_of(" ")+1, (*i).length()-(*i).find_last_of(" ")+1));
   }
+  for (std::vector<std::string>::iterator i = readonly_caches.begin(); i != readonly_caches.end(); i++) {
+    logger.msg(Arc::INFO, "\tCache (read-only): %s", *i);
+  }
   if (cache_params.cleanCache()) logger.msg(Arc::INFO, "\tCache cleaning enabled");
   else logger.msg(Arc::INFO, "\tCache cleaning disabled");
 }
@@ -294,8 +299,14 @@ const std::list<std::pair<bool,std::string> > & GMConfig::MatchingGroups(const c
   return (pos == matching_groups.end()) ? empty_group_list : pos->second;
 }
 
-bool GMConfig::Substitute(std::string& param, const Arc::User& user) const {
+const std::list<std::pair<bool,std::string> > & GMConfig::MatchingGroupsPublicInformation() const {
+  return matching_groups_publicinfo;
+}
+
+bool GMConfig::Substitute(std::string& param, bool& userSubs, bool& otherSubs, const Arc::User& user) const {
   std::string::size_type curpos = 0;
+  userSubs = false;
+  otherSubs = false;
   for (;;) {
     if (curpos >= param.length()) break;
     std::string::size_type pos = param.find('%', curpos);
@@ -304,16 +315,16 @@ bool GMConfig::Substitute(std::string& param, const Arc::User& user) const {
     if (param[pos] == '%') { curpos=pos+1; continue; };
     std::string to_put;
     switch (param[pos]) {
-      case 'R': to_put = SessionRoot(""); break; // First session dir will be used if there are multiple
-      case 'C': to_put = ControlDir(); break;
-      case 'U': to_put = user.Name(); break;
-      case 'H': to_put = user.Home(); break;
-      case 'Q': to_put = DefaultQueue(); break;
-      case 'L': to_put = DefaultLRMS(); break;
-      case 'u': to_put = Arc::tostring(user.get_uid()); break;
-      case 'g': to_put = Arc::tostring(user.get_gid()); break;
-      case 'W': to_put = Arc::ArcLocation::Get(); break;
-      case 'F': to_put = conffile; break;
+      case 'R': to_put = SessionRoot(""); otherSubs = true; break; // First session dir will be used if there are multiple
+      case 'C': to_put = ControlDir();  otherSubs = true; break;
+      case 'U': to_put = user.Name(); userSubs = true; break;
+      case 'H': to_put = user.Home(); userSubs = true; break;
+      case 'Q': to_put = DefaultQueue();  otherSubs = true; break;
+      case 'L': to_put = DefaultLRMS();  otherSubs = true; break;
+      case 'u': to_put = Arc::tostring(user.get_uid()); userSubs = true; break;
+      case 'g': to_put = Arc::tostring(user.get_gid()); userSubs = true; break;
+      case 'W': to_put = Arc::ArcLocation::Get();  otherSubs = true; break;
+      case 'F': to_put = conffile;  otherSubs = true; break;
       case 'G':
         logger.msg(Arc::ERROR, "Globus location variable substitution is not supported anymore. Please specify path directly.");
         break;
