@@ -24,9 +24,6 @@ typedef struct {
 
 static Arc::Logger& logger = Arc::Logger::getRootLogger();
 
-void (*RunParallel::kicker_func_)(void*) = NULL;
-void* RunParallel::kicker_arg_ = NULL;
-
 static void job_subst(std::string& str,void* arg) {
   job_subst_t* subs = (job_subst_t*)arg;
   for(std::string::size_type p = 0;;) {
@@ -48,13 +45,46 @@ static void job_subst(std::string& str,void* arg) {
   subs->config->Substitute(str, subs->job->get_user());
 }
 
-bool RunParallel::run(const GMConfig& config,const GMJob& job,const std::string& args,Arc::Run** ere,bool su) {
-  RunPlugin* cred = config.CredPlugin();
+class JobRefInList {
+ private:
+  JobId id;
+  JobsList& list;
+ public:
+  JobRefInList(const GMJob& job, JobsList& list): id(job.get_id()), list(list) {};
+  static void kicker(void* arg);
+};
+
+void JobRefInList::kicker(void* arg) {
+  JobRefInList* ref = reinterpret_cast<JobRefInList*>(arg);
+  if(ref) {
+    logger.msg(Arc::DEBUG,"%s: Job's helper exited",ref->id);
+    ref->list.RequestAttention(ref->id);
+    delete ref;
+  };
+}
+
+bool RunParallel::run(const GMConfig& config,const GMJob& job, JobsList& list,
+                      const std::string& args,Arc::Run** ere,bool su) {
   job_subst_t subs; subs.config=&config; subs.job=&job; subs.reason="external";
   std::string errlog = config.ControlDir()+"/job."+job.get_id()+".errors";
   std::string proxy = config.ControlDir() + "/job." + job.get_id() + ".proxy";
-  return run(config, job.get_user(), job.get_id().c_str(), errlog.c_str(),
+  JobRefInList* ref = new JobRefInList(job, list);
+  bool result = run(config, job.get_user(), job.get_id().c_str(), errlog.c_str(),
+             args, ere, proxy.c_str(), su, NULL, &job_subst, &subs, &JobRefInList::kicker, ref);
+  if(!result) delete ref;
+  return result;
+}
+
+bool RunParallel::run(const GMConfig& config,const GMJob& job,
+                      const std::string& args,Arc::Run** ere,bool su) {
+  RunPlugin* cred = NULL;
+  job_subst_t subs; subs.config=&config; subs.job=&job; subs.reason="external";
+  if((!cred) || (!(*cred))) { cred=NULL; };
+  std::string errlog = config.ControlDir()+"/job."+job.get_id()+".errors";
+  std::string proxy = config.ControlDir() + "/job." + job.get_id() + ".proxy";
+  bool result = run(config, job.get_user(), job.get_id().c_str(), errlog.c_str(),
              args, ere, proxy.c_str(), su, NULL, &job_subst, &subs);
+  return result;
 }
 
 /* fork & execute child process with stderr redirected 
@@ -63,7 +93,9 @@ bool RunParallel::run(const GMConfig& config, const Arc::User& user,
                       const char* procid, const char* errlog,
                       const std::string& args, Arc::Run** ere,
                       const char* jobproxy, bool su,
-                      RunPlugin* cred, RunPlugin::substitute_t subst, void* subst_arg) {
+                      RunPlugin* cred,
+                      RunPlugin::substitute_t subst, void* subst_arg,
+                      void (*kicker_func)(void*), void* kicker_arg) {
   *ere=NULL;
   Arc::Run* re = new Arc::Run(args);
   if((!re) || (!(*re))) {
@@ -71,7 +103,7 @@ bool RunParallel::run(const GMConfig& config, const Arc::User& user,
     logger.msg(Arc::ERROR,"%s: Failure creating slot for child process",procid?procid:"");
     return false;
   };
-  if(kicker_func_) re->AssignKicker(kicker_func_,kicker_arg_);
+  if(kicker_func) re->AssignKicker(kicker_func,kicker_arg);
   RunParallel* rp = new RunParallel(procid,errlog,cred,subst,subst_arg);
   if((!rp) || (!(*rp))) {
     if(rp) delete rp;
@@ -129,9 +161,6 @@ bool RunParallel::run(const GMConfig& config, const Arc::User& user,
 }
 
 void RunParallel::initializer(void* arg) {
-#ifdef WIN32
-#error This functionality is not available in Windows environment
-#else
   // child
   RunParallel* it = (RunParallel*)arg;
   if(it->cred_) {
@@ -156,7 +185,6 @@ void RunParallel::initializer(void* arg) {
   }
   else { h=::open("/dev/null",O_WRONLY); };
   if(h != 2) { if(dup2(h,2) != 2) { sleep(10); exit(1); }; close(h); };
-#endif
 }
 
 } // namespace ARex
