@@ -1,5 +1,16 @@
 package Condor;
 
+######################################################################
+# DISCLAIMER
+######################################################################
+# This module depends on ARC0mod.pm which is obsolete and deprecated 
+# starting from ARC 6.0 
+# Please DO NOT build new LRMS modules based on this one but follow
+# the indications in
+#                       LRMSInfo.pm
+# instead.
+######################################################################
+
 use strict;
 use POSIX;
 our @ISA = ('Exporter');
@@ -427,6 +438,12 @@ sub condor_job_hold_isstaging($) {
     return 0 unless $alljobdata{$id};
     return 1 if ($alljobdata{$id}{lc 'HoldReasonCode'} == '16');
     
+    # E state means the job will not exit the HOLD state.
+    # O state means the job can be out of the HOLD state.
+    # If HoldReasonCode == 16 --> staging --> O
+    my $substate = 'E';
+    $substate = 'O' if $alljobdata{$id}{lc 'HoldReasonCode'} == '16';
+    return $substate;
 }
 
 #
@@ -466,7 +483,7 @@ sub cluster_info ($) {
 
     my %lrms_cluster;
 
-    configure_condor_env(%$config) or die "Condor executables or config file not found\n";
+    configure_condor_env(%$config) or error("Condor executables (in condor_bin_path) or config file (condor_config) not found, check configuration. Exiting...");
 
     collect_node_data();
     collect_job_data();
@@ -512,11 +529,11 @@ sub queue_info ($$) {
     warning("Option 'condor_requirements' is not defined for queue $qname") unless $qdef;
     debug("===Requirements for queue $qname: $qdef");
     
-    configure_condor_env(%$config) or die "Condor executables or config file not found\n";
+    configure_condor_env(%$config) or error("Condor executables (in condor_bin_path) or config file (condor_config) not found, check configuration. Exiting...");
 
     collect_node_data();
     collect_job_data();
-    collect_jobids($qname, $$config{control}{'.'}{controldir});
+    collect_jobids($qname, $$config{controldir});
 
     # Number of available (free) cpus can not be larger that
     # free cpus in the whole cluster
