@@ -3,7 +3,10 @@ Client for retrieving cache. Note that json is only available on python >= 2.6.
 """
 
 import json
-from urllib import quote
+try:
+    from urllib.parse import quote
+except ImportError:
+    from urllib import quote
 
 from twisted.python import log
 from twisted.web import client
@@ -16,14 +19,13 @@ class InvalidIndexReplyError(Exception):
 
 
 def queryIndex(index_url, urls):
-
     for url in urls: assert ',' not in urls, "Commas ',' not allowed in urls currently"
 
     eurls = [ quote(url) for url in urls ]
 
     url = index_url + "?url=" + ','.join(eurls)
 
-    d = client.getPage(url)
+    d = client.getPage(url.encode())
     d.addCallback(_gotResult, index_url)
     d.addErrback(_indexError, index_url)
     return d
@@ -35,7 +37,7 @@ def _gotResult(result, index_url):
     try:
         decoded_result = json.loads(result)
         return decoded_result
-    except ValueError, e:
+    except ValueError as e:
         raise InvalidIndexReplyError(str(e))
 
 
